@@ -4,5 +4,5 @@ class Module1(object):
     def __init__(self):
         x = 0
 
-    def func1(self, a, b):
+    def func1(a, b):
         return a + b
\ No newline at end of file
