@@ -4,5 +4,5 @@ class Module2(object):
     def __init__(self):
         x = 0
 
-    def func2(self, a, b):
+    def func2(a, b):
         return a * b
\ No newline at end of file
